============================
geoffrey-csslint
============================

.. image:: https://badge.fury.io/py/geoffrey-csslint.png
    :target: http://badge.fury.io/py/geoffrey-csslint
    
.. image:: https://travis-ci.org/GeoffreyCI/geoffrey-csslint.png?branch=master
        :target: https://travis-ci.org/GeoffreyCI/geoffrey-csslint

.. image:: https://pypip.in/d/geoffrey-csslint/badge.png
        :target: https://pypi.python.org/pypi/geoffrey-csslint


CSSLint is a tool to help point out problems with your CSS code.

Geoffrey wrapper for CSSLint utility: https://github.com/CSSLint/csslint.git

* Free software: GPLv3
* Documentation: http://geoffrey-csslint.readthedocs.org.

Configuration
-------------

To correctly use this plugin you must define the variable *csslint_path* in the plugin's section of your project


Features
--------

* TODO
